@@ -7,9 +7,9 @@ use warnings;
 use parent 'TableData::Munge::Concat';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-25'; # DATE
+our $DATE = '2023-11-26'; # DATE
 our $DIST = 'TableDataBundle-Perl-CPAN-Release'; # DIST
-our $VERSION = '20231120.3'; # VERSION
+our $VERSION = '20231126.0'; # VERSION
 
 sub new {
     my $self = shift;
@@ -20,7 +20,7 @@ sub new {
     $self->SUPER::new(tabledatalist => \@tabledatalist);
 }
 
-# STATS
+our %STATS = ("num_columns",9,"num_rows",362347); # STATS
 
 1;
 # ABSTRACT: CPAN releases (from newest to oldest)
@@ -37,7 +37,7 @@ TableData::Perl::CPAN::Release::Static::FromNewest - CPAN releases (from newest
 
 =head1 VERSION
 
-This document describes version 20231120.3 of TableData::Perl::CPAN::Release::Static::FromNewest (from Perl distribution TableDataBundle-Perl-CPAN-Release), released on 2023-11-25.
+This document describes version 20231126.0 of TableData::Perl::CPAN::Release::Static::FromNewest (from Perl distribution TableDataBundle-Perl-CPAN-Release), released on 2023-11-26.
 
 =head1 SYNOPSIS
 
